@@ -1,10 +1,22 @@
-project = 'python-tackerclient'
+# -*- coding: utf-8 -*-
+#
 
 # -- General configuration ---------------------------------------------
 
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx']
+extensions = [
+    'sphinx.ext.autodoc',
+    'reno.sphinxext',
+    'openstackdocstheme',
+    'cliff.sphinxext',
+]
+
+# openstackdocstheme options
+repository_name = 'openstack/python-tackerclient'
+bug_project = 'python-tackerclient'
+bug_tag = 'doc'
+html_last_updated_fmt = '%Y-%m-%d %H:%M'
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -32,21 +44,11 @@ pygments_style = 'sphinx'
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
 # Sphinx are currently 'default' and 'sphinxdoc'.
-html_theme = 'nature'
+html_theme = 'openstackdocs'
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'tackerclientdoc'
 
+# -- Options for cliff.sphinxext plugin ---------------------------------------
 
-# Grouping the document tree into LaTeX files. List of tuples
-# (source start file, target name, title, author,
-#  documentclass [howto/manual]).
-latex_documents = [
-  ('index',
-    '%s.tex' % project,
-    u'%s Documentation' % project,
-    u'OpenStack Foundation', 'manual'),
-]
-
-# Example configuration for intersphinx: refer to the Python standard library.
-intersphinx_mapping = {'http://docs.python.org/': None}
+autoprogram_cliff_application = 'openstack'
