@@ -12,6 +12,7 @@
 
 import yaml
 
+from tackerclient.common import exceptions
 from tackerclient.i18n import _
 from tackerclient.tacker import v1_0 as tackerV10
 
@@ -50,6 +51,9 @@ class CreateNS(tackerV10.CreateCommand):
         nsd_group.add_argument(
             '--nsd-id',
             help=_('NSD ID to use as template to create NS'))
+        nsd_group.add_argument(
+            '--nsd-template',
+            help=_('NSD file to create NS'))
         nsd_group.add_argument(
             '--nsd-name',
             help=_('NSD name to use as template to create NS'))
@@ -88,11 +92,25 @@ class CreateNS(tackerV10.CreateCommand):
                                                               parsed_args.
                                                               nsd_name)
                 parsed_args.nsd_id = _id
+        elif parsed_args.nsd_template:
+            with open(parsed_args.nsd_template) as f:
+                template = f.read()
+            try:
+                args['nsd_template'] = yaml.load(
+                    template, Loader=yaml.SafeLoader)
+            except yaml.YAMLError as e:
+                raise exceptions.InvalidInput(e)
+            if not args['nsd_template']:
+                raise exceptions.InvalidInput('The nsd file is empty')
+
         if parsed_args.param_file:
             with open(parsed_args.param_file) as f:
                 param_yaml = f.read()
-            args['attributes']['param_values'] = yaml.load(
-                param_yaml, Loader=yaml.SafeLoader)
+            try:
+                args['attributes']['param_values'] = yaml.load(
+                    param_yaml, Loader=yaml.SafeLoader)
+            except yaml.YAMLError as e:
+                raise exceptions.InvalidInput(e)
         tackerV10.update_dict(parsed_args, body[self.resource],
                               ['tenant_id', 'name', 'description',
                                'nsd_id', 'vim_id'])
