@@ -67,7 +67,11 @@ class CreateVIM(tackerV10.CreateCommand):
         if parsed_args.config_file:
             with open(parsed_args.config_file) as f:
                 vim_config = f.read()
-                config_param = yaml.load(vim_config, Loader=yaml.SafeLoader)
+                try:
+                    config_param = yaml.load(vim_config,
+                                             Loader=yaml.SafeLoader)
+                except yaml.YAMLError as e:
+                    raise exceptions.InvalidInput(e)
         vim_obj = body[self.resource]
         try:
             auth_url = config_param.pop('auth_url')
@@ -76,7 +80,6 @@ class CreateVIM(tackerV10.CreateCommand):
                                                            'specified',
                                                    status_code=404)
         vim_obj['auth_url'] = vim_utils.validate_auth_url(auth_url).geturl()
-        vim_obj['type'] = config_param.pop('type', 'openstack')
         vim_utils.args2body_vim(config_param, vim_obj)
         tackerV10.update_dict(parsed_args, body[self.resource],
                               ['tenant_id', 'name', 'description',
@@ -113,13 +116,19 @@ class UpdateVIM(tackerV10.UpdateCommand):
         if parsed_args.config_file:
             with open(parsed_args.config_file) as f:
                 config_yaml = f.read()
-            config_param = yaml.load(config_yaml)
+            try:
+                config_param = yaml.load(config_yaml)
+            except yaml.YAMLError as e:
+                raise exceptions.InvalidInput(e)
         vim_obj = body[self.resource]
         if config_param is not None:
             vim_utils.args2body_vim(config_param, vim_obj)
         tackerV10.update_dict(parsed_args, body[self.resource],
                               ['tenant_id', 'name', 'description',
                                'is_default'])
+        # type attribute is read-only, it can't be updated, so remove it
+        # in update method
+        body['vim'].pop('type', None)
         return body
 
 
