@@ -391,10 +391,11 @@ class Client(ClientBase):
                                retrieve_all,
                                **_params)
         for vnfd in vnfds_dict['vnfds']:
-            if 'description' in vnfd.keys() and \
-                len(vnfd['description']) > DEFAULT_DESC_LENGTH:
-                vnfd['description'] = vnfd['description'][:DEFAULT_DESC_LENGTH]
-                vnfd['description'] += '...'
+            if vnfd.get('description'):
+                if len(vnfd['description']) > DEFAULT_DESC_LENGTH:
+                    vnfd['description'] = \
+                        vnfd['description'][:DEFAULT_DESC_LENGTH]
+                    vnfd['description'] += '...'
         return vnfds_dict
 
     @APIParamsCall
@@ -404,10 +405,6 @@ class Client(ClientBase):
 
     @APIParamsCall
     def create_vnfd(self, body):
-        if ("tosca_definitions_version" not in
-           body[self._VNFD]['attributes']['vnfd']):
-            _logger.warning("VNFD legacy templates are deprecated. Please "
-                            "use NFV TOSCA templates.")
         body[self._VNFD]['service_types'] = [{'service_type': 'vnfd'}]
         return self.post(self.vnfds_path, body)
 
